summaryrefslogtreecommitdiffstats
path: root/ecomp-portal-BE-os/src/main/java/org/onap/portalapp/portal/service/UserRolesServiceImpl.java
diff options
context:
space:
mode:
Diffstat (limited to 'ecomp-portal-BE-os/src/main/java/org/onap/portalapp/portal/service/UserRolesServiceImpl.java')
-rw-r--r--ecomp-portal-BE-os/src/main/java/org/onap/portalapp/portal/service/UserRolesServiceImpl.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/ecomp-portal-BE-os/src/main/java/org/onap/portalapp/portal/service/UserRolesServiceImpl.java b/ecomp-portal-BE-os/src/main/java/org/onap/portalapp/portal/service/UserRolesServiceImpl.java
index c0d14f60..2bfc9d68 100644
--- a/ecomp-portal-BE-os/src/main/java/org/onap/portalapp/portal/service/UserRolesServiceImpl.java
+++ b/ecomp-portal-BE-os/src/main/java/org/onap/portalapp/portal/service/UserRolesServiceImpl.java
@@ -33,7 +33,7 @@
*
* ============LICENSE_END============================================
*
- * ECOMP is a trademark and service mark of AT&T Intellectual Property.
+ *
*/
package org.onap.portalapp.portal.service;
@@ -98,13 +98,13 @@ public class UserRolesServiceImpl extends UserRolesCommonServiceImpl implements
public static void persistExternalRoleInEcompDb(EPRole externalAppRole, Long appId, EPRoleService roleService) {
externalAppRole.setAppId(appId);
externalAppRole.setAppRoleId(externalAppRole.getId());
- externalAppRole.setId(null); // We will persist a new role, with ecomp
+ externalAppRole.setId(null); // We will persist a new role, with onap
// role id which will be different than
// external app role id.
roleService.saveRole(externalAppRole);
logger.debug(EELFLoggerDelegate.debugLogger,
- String.format("ECOMP persists role from app:%d, app roleId: %d, roleName: %s", appId,
+ String.format("ONAP persists role from app:%d, app roleId: %d, roleName: %s", appId,
externalAppRole.getAppRoleId(), externalAppRole.getName()));
}